@@ -14,7 +14,7 @@ def train(
         fit_f, eval_f=None, get_net=None, get_loss=None, get_trainer=None, save_params=None,
         enable_hyper_search=False, reporthook=None, final_reporthook=None, primary_key=None,
         eval_epoch=1, initial_net=True, net_init=None, batch_lr_scheduler=None, epoch_lr_scheduler=None,
-        loss_as_dict=False, **cfg_kwargs
+        loss_as_dict=False, verbose=None, dump_cfg=None, **cfg_kwargs
 ):
     if initial_net:
         net_init = _net_init if net_init is None else net_init
@@ -38,5 +38,5 @@ def train(
         final_reporthook=final_reporthook,
         primary_key=primary_key, eval_epoch=eval_epoch, loss_dict2tmt_loss=loss_dict2tmt_torch_loss,
         batch_lr_scheduler=batch_lr_scheduler, epoch_lr_scheduler=epoch_lr_scheduler, loss_as_dict=loss_as_dict,
-        **cfg_kwargs
+        verbose=verbose, dump_cfg=dump_cfg, **cfg_kwargs
     )
