@@ -1,5 +1,5 @@
 # coding: utf-8
 # create by tongshiwei on 2019-8-30
 
+from .utils import pick, tensor2list
 from .sequence import sequence_mask
-from .configuration import Configuration, ConfigurationParser
